@@ -8,5 +8,8 @@ fn main() {
         send BUTTON_PRESSED_EVENT_CODE from device_address to receiver_address;
     ";
 
-    println!("{:?}", Parser::parse(text))
+    match Parser::parse(text) {
+        Ok(event_processors) => println!("{:?}", event_processors),
+        Err(err) => println!("{}", err),
+    }
 }
